#
# spec file for package osmo-trx
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-trx
Version:        1.4.0
Release:        bp154.1.49
Summary:        SDR transceiver that implements Layer 1 of a GSM BTS
License:        AGPL-3.0-or-later
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/osmotrx/wiki/OsmoTRX
Source:         %{name}-%{version}.tar.xz
Patch0:         harden_osmo-trx-lms.service.patch
Patch1:         harden_osmo-trx-uhd.service.patch
Patch2:         harden_osmo-trx-usrp1.service.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  pkgconfig(LimeSuite)
BuildRequires:  pkgconfig(fftw3f)
BuildRequires:  pkgconfig(libosmocodec) >= 1.6.0
BuildRequires:  pkgconfig(libosmocoding) >= 1.6.0
BuildRequires:  pkgconfig(libosmocore) >= 1.6.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.6.0
BuildRequires:  pkgconfig(libosmogsm) >= 1.6.0
BuildRequires:  pkgconfig(libosmovty) >= 1.6.0
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(uhd)
BuildRequires:  pkgconfig(usrp) >= 3.3
%{?systemd_requires}
%if 0%{?suse_version} > 1325
BuildRequires:  libboost_program_options-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_test-devel
BuildRequires:  libboost_thread-devel
%else
BuildRequires:  boost-devel
%endif

%description
OsmoTRX is a software-defined radio transceiver that implements the Layer 1
physical layer of a BTS comprising the following 3GPP specifications:

TS 05.01 "Physical layer on the radio path"
TS 05.02 "Multiplexing and Multiple Access on the Radio Path"
TS 05.04 "Modulation"
TS 05.10 "Radio subsystem synchronization"

In this context, BTS is "Base transceiver station". It's the stations that
connect mobile phones to the mobile network.

3GPP is the "3rd Generation Partnership Project" which is the collaboration
between different telecommunication associations for developing new
generations of mobile phone networks. (post-2G/GSM)

%package uhd
Summary:        SDR transceiver that implements Layer 1 of a GSM BTS (UHD)
Group:          Productivity/Telephony/Servers

%description uhd
OsmoTRX is a software-defined radio transceiver that implements the Layer 1
physical layer of a BTS comprising the following 3GPP specifications:

TS 05.01 "Physical layer on the radio path"
TS 05.02 "Multiplexing and Multiple Access on the Radio Path"
TS 05.04 "Modulation"
TS 05.10 "Radio subsystem synchronization"

In this context, BTS is "Base transceiver station". It's the stations that
connect mobile phones to the mobile network.

3GPP is the "3rd Generation Partnership Project" which is the collaboration
between different telecommunication associations for developing new
generations of mobile phone networks. (post-2G/GSM)

%package usrp1
Summary:        SDR transceiver that implements Layer 1 of a GSM BTS (USRP1)
Group:          Productivity/Telephony/Servers

%description usrp1
OsmoTRX is a software-defined radio transceiver that implements the Layer 1
physical layer of a BTS comprising the following 3GPP specifications:

TS 05.01 "Physical layer on the radio path"
TS 05.02 "Multiplexing and Multiple Access on the Radio Path"
TS 05.04 "Modulation"
TS 05.10 "Radio subsystem synchronization"

In this context, BTS is "Base transceiver station". It's the stations that
connect mobile phones to the mobile network.

3GPP is the "3rd Generation Partnership Project" which is the collaboration
between different telecommunication associations for developing new
generations of mobile phone networks. (post-2G/GSM)

%package lms
Summary:        SDR transceiver that implements Layer 1 of a GSM BTS (LimeSuite)
Group:          Productivity/Telephony/Servers

%description lms
OsmoTRX is a software-defined radio transceiver that implements the Layer 1
physical layer of a BTS comprising the following 3GPP specifications:

TS 05.01 "Physical layer on the radio path"
TS 05.02 "Multiplexing and Multiple Access on the Radio Path"
TS 05.04 "Modulation"
TS 05.10 "Radio subsystem synchronization"

In this context, BTS is "Base transceiver station". It's the stations that
connect mobile phones to the mobile network.

3GPP is the "3rd Generation Partnership Project" which is the collaboration
between different telecommunication associations for developing new
generations of mobile phone networks. (post-2G/GSM)

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1

%build
echo "%{version}" >.tarball-version
autoreconf -fiv
%configure \
    --docdir=%{_docdir}/%{name} \
    --with-systemdsystemunitdir=%{_unitdir} \
    --with-lms \
    --with-uhd \
    --with-usrp1
make V=1 %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-trx-lms
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-trx-uhd
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-trx-usrp1
%fdupes -s %{buildroot}/%{_datadir}

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%pre lms
%service_add_pre osmo-trx-lms.service

%post lms
%service_add_post osmo-trx-lms.service

%preun lms
%service_del_preun osmo-trx-lms.service

%postun lms
%service_del_postun osmo-trx-lms.service

%pre uhd
%service_add_pre osmo-trx-uhd.service

%post uhd
%service_add_post osmo-trx-uhd.service

%preun uhd
%service_del_preun osmo-trx-uhd.service

%postun uhd
%service_del_postun osmo-trx-uhd.service

%pre usrp1
%service_add_pre osmo-trx-usrp1.service

%post usrp1
%service_add_post osmo-trx-usrp1.service

%preun usrp1
%service_del_preun osmo-trx-usrp1.service

%postun usrp1
%service_del_postun osmo-trx-usrp1.service

%files
%license COPYING
%doc README.md
%doc %{_docdir}/%{name}/examples

%files lms
%{_bindir}/osmo-trx-lms
%{_sbindir}/rcosmo-trx-lms
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-trx-lms.cfg
%{_unitdir}/osmo-trx-lms.service

%files uhd
%{_bindir}/osmo-trx-uhd
%{_sbindir}/rcosmo-trx-uhd
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-trx-uhd.cfg
%{_unitdir}/osmo-trx-uhd.service

%files usrp1
%{_bindir}/osmo-trx-usrp1
%{_sbindir}/rcosmo-trx-usrp1
%dir %{_datadir}/usrp
%dir %{_datadir}/usrp/rev2
%dir %{_datadir}/usrp/rev4
%{_datadir}/usrp/rev2/std_inband.rbf
%{_datadir}/usrp/rev4/std_inband.rbf
%{_unitdir}/osmo-trx-usrp1.service

%changelog
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.4.0
  * https://git.osmocom.org/osmo-trx/plain/debian/changelog?h=1.4.0
* Wed Oct 13 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_osmo-trx-lms.service.patch
  * harden_osmo-trx-uhd.service.patch
  * harden_osmo-trx-usrp1.service.patch
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * Transceiver: Fix wrong response upon CMD HANDOVER failure
  * radioDevice: Introduce getTxGain() API
  * Drop old setPriority related code
- Update to new upstream release 1.1.0
  * Transceiver: Store TRXD version per channel
  * Bind CTRL port to IP addr specified in VTY config
  * Transceiver: Support TRXD v1
  * Transceiver: Support SETFORMAT command
  * Add VTY commands to set error ctr thresholds
  * lms: Log underrun/overrun events
  * VTY: add extended (11-bit) RACH detection toggle
* Tue Jan 29 2019 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * Introduce OsmoTRX user manual
  * Direct support of LimeSuite as osmo-trx-lms without the detour
    of uhd+soapy-uhd+soapysdr
  * split device-specific parts into their own classes + binaries:
    osmo-trx-{uhd,lms,usrp1}
  * make better use of diferent logging sub-systems / log levels
  * Full changelogs since 0.2.0:
    http://git.osmocom.org/osmo-trx/plain/debian/changelog?h=1.0.0
    http://git.osmocom.org/osmo-trx/plain/debian/changelog?h=0.4.0
    http://git.osmocom.org/osmo-trx/plain/debian/changelog?h=0.3.0
- Create dedicated subpackages for each supported device-type
  * lms
  * uhd
  * usrp1
* Thu Dec 28 2017 mardnh@gmx.de
- Update to new upstream release 0.2.0
  * No changelog was provided
- Specfile cleanup
* Wed Mar 22 2017 mardnh@gmx.de
- Update to version 0.0.0.git1490207482.38b6987:
  * uhd: Add support for UHD-3.11 logging control
  * uhd: Increase MC-BTS FPGA clock rate to 51.2 MHz
  * Add autoconf-archive to dependencies
  * CommonLibs: Remove unused files.
  * sigProcLib: Typo sybols -> symbols
  * radioBuffer: Remove extra ; at the end of inline function definitions.
  * sigProcLib: Fix documentation, sync argument names in .cpp and .h files.
  * sigProcLib: make energyDetect() simpler by returning actual energy.
  * sigProcLib: Rename demodulateBurst() to demodGmskBurst() for clarity.
  * sigProcLib: Slice SoftVector instead of signalVector for GMSK demod.
  * Call vectorSlicer() right before packing bits for transmission to osmo-bts.
  * CommonLibs: Print soft bits with less confidence to console when printing a soft vector.
  * BitVector: Remove convolutional codec - we don't use it in osmo-trx.
  * BitVector: Convert SoftVector from 0..1 to -1..+1 soft bits.
* Fri Mar  3 2017 mardnh@gmx.de
- Update to version 0.0.0.git1485446766.2dee3e9:
  * uhd: Add X300 sample timing for 4 SPS
  * Revert "uhd: Set minimum supported version to 3.9.0"
  * debian: Require fftw3 header files for osmo-trx
  * Add gerrit settings
  * Integrate Debian packaging changes
  * Do not embed sqlite3 when building
  * Remove embedded sqlite3
  * Fix building against sqlite3
* Wed Dec 28 2016 mardnh@gmx.de
- initial package
